#!/bin/sh

#  mirrpg v. 0.0.2
#  Copyright (C) 2001 Davide Angelocola
#  Updated by Calle Laakkonen in 2004
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License as
#  published by the Free Software Foundation; either version 2 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this library; if not, write to the Free Software
#  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#  Author: Davide Angelocola <davide178@inwind.it>

options="--indent-level4"
options="$options --ignore-profile"
options="$options --preserve-mtime"
options="$options -br"
options="$options -cdw"
options="$options -lp"
options="$options -brs"
options="$options -nbfda"
options="$options -nbfde"
options="$options -npsl"
options="$options -ce"
options="$options -nut"

for coin in *.[ch]
do
 echo "indenting... $coin"
 indent $options $coin 
 rm $coin~ -f
done 
